@@ -31,8 +31,8 @@ class Builder:
         if DRIVE_LINK_PREFIX in link:
             doc_id = link.split(DRIVE_LINK_PREFIX)[1].split(DRIVE_LINK_END)[0]
 
-            for doc in self.drive.docs():
-                if doc_id == doc.id:
+            for each_file in self.drive.media(public=True):
+                if doc_id == each_file.id:
                     for folder in self.drive.folders():
                         if folder.id == doc.parents:
                             break
@@ -40,9 +40,20 @@ class Builder:
                         print("folder not found!")
                         return link
 
-                    path = f'{self.path_join(folder, "")}{doc.pointer.lower().replace(" ", "_")}.html'
-
+                    path = f'{self.path_join(folder, "")}{doc.pointer.lower().replace(" ", "_")}'
                     return path
+            else:
+                for doc in self.drive.docs(public=True):
+                    if doc_id == doc.id:
+                        for folder in self.drive.folders():
+                            if folder.id == doc.parents:
+                                break
+                        else:
+                            print("folder not found!")
+                            return link
+
+                        path = f'{self.path_join(folder, "")}{doc.pointer.lower().replace(" ", "_")}.html'
+                        return path
 
         return link
 
